;; Generated package description from sxhkdrc-mode.el  -*- no-byte-compile: t -*-
(define-package "sxhkdrc-mode" "0.1.4" "Major mode for sxhkdrc files (Simple X Hot Key Daemon)" '((emacs "27.1")) :commit "95b2c324f8ab66f1ca9eaee89fda54a535e06d6a" :authors '(("Protesilaos Stavrou" . "info@protesilaos.com")) :maintainer '("Protesilaos Stavrou General Issues" . "~protesilaos/general-issues@lists.sr.ht") :url "https://git.sr.ht/~protesilaos/sxhkdrc-mode")
